# PGAA - Pygame-CE Anti-Aliasing

[![CodeQL](https://github.com/Iron-Sparrow/PGAA/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/github-code-scanning/codeql)
![PyPi Version](https://img.shields.io/pypi/v/pgaa.svg?v=1)
[![Upload Python Package](https://github.com/Iron-Sparrow/PGAA/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/python-publish.yml)
[![Test Package Compatibility on Ubuntu (x64)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_ubuntu.yml/badge.svg?branch=main)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_ubuntu.yml)
[![Test Package Compatibility on Windows (x64)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_windows.yml/badge.svg)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_windows.yml)
[![Test Package Compatibility on MacOS](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_mac.yml/badge.svg)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_mac.yml)
[![Test Package Compatibility on Ubuntu ARM](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_ubuntu_arm.yml/badge.svg)](https://github.com/Iron-Sparrow/PGAA/actions/workflows/test_ubuntu_arm.yml)
*This package is not compatible with Windows on ARM*


<ins>***This project is very new and still under development. Expect bugs, issues, and incomplete features.
This project is not affiliated with the Pygame-CE project.***</ins>

## Dowload and Install

 ```python -m pip install pgaa``` or check out the [releases](https://github.com/Iron-Sparrow/PGAA/releases).

## Updating the package

```python -m pip install --upgrade pgaa```

## Getting Started

After you've installed PGAA, you can check out the documentation.

## Documentation

Documentation can be found at [in the docs folder](https://github.com/Iron-Sparrow/PGAA/blob/main/docs/Documentation.md).
